@@ -1,5 +1,9 @@
+use once_cell::sync::Lazy;
+
 use crate::{ConfigDevice, ConfigSettings, ConfigWindow};
 
+pub static CONFIGS: Lazy<Configs> = Lazy::new(Configs::load);
+
 #[derive(Default, Clone, PartialEq, Debug)]
 pub struct Configs {
     pub settings: ConfigSettings,
@@ -8,6 +12,8 @@ pub struct Configs {
 }
 
 impl Configs {
+    /// This should only be used directly to load fresh configs;
+    /// use `CONFIGS` instead to access the initial instance
     pub fn load() -> Self {
         Configs {
             settings: ConfigSettings::load(),
