@@ -1,8 +1,10 @@
 use crate::networking::types::address_port_pair::AddressPortPair;
 
 /// This enum defines the currently displayed modal.
-#[derive(PartialEq, Eq, Clone, Debug)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 pub enum MyModal {
+    /// Reset modal.
+    Reset,
     /// Quit modal.
     Quit,
     /// Clear all modal.
