@@ -3,7 +3,6 @@
 //! It contains elements to display traffic statistics: chart, detailed connections data
 //! and overall statistics about the filtered traffic.
 
-use iced::alignment::{Horizontal, Vertical};
 use iced::widget::scrollable::Direction;
 use iced::widget::text::LineHeight;
 use iced::widget::tooltip::Position;
@@ -12,11 +11,12 @@ use iced::widget::{
     Scrollable, Space, Text, Tooltip,
 };
 use iced::Length::{Fill, FillPortion};
-use iced::{Alignment, Font, Length};
+use iced::{Alignment, Font, Length, Padding};
 
 use crate::countries::country_utils::get_flag_tooltip;
 use crate::countries::flags_pictures::FLAGS_WIDTH_BIG;
 use crate::gui::components::tab::get_pages_tabs;
+use crate::gui::sniffer::Sniffer;
 use crate::gui::styles::button::ButtonType;
 use crate::gui::styles::container::ContainerType;
 use crate::gui::styles::rule::RuleType;
@@ -25,7 +25,6 @@ use crate::gui::styles::style_constants::FONT_SIZE_TITLE;
 use crate::gui::styles::text::TextType;
 use crate::gui::styles::types::palette_extension::PaletteExtension;
 use crate::gui::types::message::Message;
-use crate::gui::types::sniffer::Sniffer;
 use crate::networking::types::data_info::DataInfo;
 use crate::networking::types::filters::Filters;
 use crate::networking::types::host::Host;
@@ -118,7 +117,7 @@ pub fn overview_page(sniffer: &Sniffer) -> Container<Message, StyleType> {
                     .width(Length::Fill)
                     .padding(10)
                     .spacing(10)
-                    .align_items(Alignment::Center)
+                    .align_x(Alignment::Center)
                     .push(
                         Row::new()
                             .spacing(10)
@@ -142,12 +141,12 @@ pub fn overview_page(sniffer: &Sniffer) -> Container<Message, StyleType> {
     Container::new(Column::new().push(tab_and_body.push(body))).height(Length::Fill)
 }
 
-fn body_no_packets(
+fn body_no_packets<'a>(
     device: &MyDevice,
     font: Font,
     language: Language,
     waiting: &str,
-) -> Column<'static, Message, StyleType> {
+) -> Column<'a, Message, StyleType> {
     let link_type = device.link_type;
     let mut adapter_info = device.name.clone();
     adapter_info.push_str(&format!("\n{}", link_type.full_print_on_one_line(language)));
@@ -155,21 +154,21 @@ fn body_no_packets(
         (
             Icon::Warning.to_text().size(60),
             unsupported_link_type_translation(language, &adapter_info)
-                .horizontal_alignment(Horizontal::Center)
+                .align_x(Alignment::Center)
                 .font(font),
         )
     } else if device.addresses.lock().unwrap().is_empty() {
         (
             Icon::Warning.to_text().size(60),
             no_addresses_translation(language, &adapter_info)
-                .horizontal_alignment(Horizontal::Center)
+                .align_x(Alignment::Center)
                 .font(font),
         )
     } else {
         (
             Icon::get_hourglass(waiting.len()).size(60),
             waiting_translation(language, &adapter_info)
-                .horizontal_alignment(Horizontal::Center)
+                .align_x(Alignment::Center)
                 .font(font),
         )
     };
@@ -178,7 +177,7 @@ fn body_no_packets(
         .width(Length::Fill)
         .padding(10)
         .spacing(10)
-        .align_items(Alignment::Center)
+        .align_x(Alignment::Center)
         .push(vertical_space())
         .push(icon_text)
         .push(Space::with_height(15))
@@ -187,23 +186,23 @@ fn body_no_packets(
         .push(Space::with_height(FillPortion(2)))
 }
 
-fn body_no_observed(
+fn body_no_observed<'a>(
     filters: &Filters,
     observed: u128,
     font: Font,
     font_headers: Font,
     language: Language,
     waiting: &str,
-) -> Column<'static, Message, StyleType> {
+) -> Column<'a, Message, StyleType> {
     let tot_packets_text = some_observed_translation(language, observed)
-        .horizontal_alignment(Horizontal::Center)
+        .align_x(Alignment::Center)
         .font(font);
 
     Column::new()
         .width(Length::Fill)
         .padding(10)
         .spacing(10)
-        .align_items(Alignment::Center)
+        .align_x(Alignment::Center)
         .push(vertical_space())
         .push(Icon::Funnel.to_text().size(60))
         .push(get_active_filters_col(
@@ -219,22 +218,22 @@ fn body_no_observed(
         .push(Space::with_height(FillPortion(2)))
 }
 
-fn body_pcap_error(
-    pcap_error: &str,
-    waiting: &str,
+fn body_pcap_error<'a>(
+    pcap_error: &'a str,
+    waiting: &'a str,
     language: Language,
     font: Font,
-) -> Column<'static, Message, StyleType> {
+) -> Column<'a, Message, StyleType> {
     // let err_string = pcap_error.clone().unwrap();
     let error_text = error_translation(language, pcap_error)
-        .horizontal_alignment(Horizontal::Center)
+        .align_x(Alignment::Center)
         .font(font);
 
     Column::new()
         .width(Length::Fill)
         .padding(10)
         .spacing(10)
-        .align_items(Alignment::Center)
+        .align_x(Alignment::Center)
         .push(vertical_space())
         .push(Icon::Error.to_text().size(60))
         .push(Space::with_height(15))
@@ -243,29 +242,29 @@ fn body_pcap_error(
         .push(Space::with_height(FillPortion(2)))
 }
 
-fn lazy_row_report(sniffer: &Sniffer) -> Container<'static, Message, StyleType> {
+fn lazy_row_report<'a>(sniffer: &Sniffer) -> Container<'a, Message, StyleType> {
     let col_host = col_host(840.0, sniffer);
     let col_service = col_service(250.0, sniffer);
 
     let row_report = Row::new()
-        .padding([0, 10, 5, 10])
+        .padding(Padding::new(10.0).top(0).bottom(5))
         .push(col_host)
         .push(Rule::vertical(40))
         .push(col_service);
 
     Container::new(row_report)
         .height(FillPortion(4))
-        .style(ContainerType::BorderedRound)
+        .class(ContainerType::BorderedRound)
 }
 
-fn col_host(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleType> {
+fn col_host<'a>(width: f32, sniffer: &Sniffer) -> Column<'a, Message, StyleType> {
     let ConfigSettings {
         style, language, ..
     } = sniffer.configs.lock().unwrap().settings;
     let font = style.get_extension().font;
     let chart_type = sniffer.traffic_chart.chart_type;
 
-    let mut scroll_host = Column::new().width(width).align_items(Alignment::Center);
+    let mut scroll_host = Column::new().width(width).align_x(Alignment::Center);
     let entries = get_host_entries(&sniffer.info_traffic, chart_type, sniffer.host_sort_type);
     let first_entry_data_info = entries
         .iter()
@@ -310,7 +309,7 @@ fn col_host(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleType
             .push(get_bars(incoming_bar_len, outgoing_bar_len));
 
         let content = Row::new()
-            .align_items(Alignment::Center)
+            .align_y(Alignment::Center)
             .spacing(5)
             .push(star_button)
             .push(get_flag_tooltip(
@@ -324,9 +323,9 @@ fn col_host(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleType
 
         scroll_host = scroll_host.push(
             button(content)
-                .padding([5, 15, 5, 10])
+                .padding(Padding::new(5.0).right(15).left(10))
                 .on_press(Message::Search(SearchParameters::new_host_search(host)))
-                .style(ButtonType::Neutral),
+                .class(ButtonType::Neutral),
         );
     }
 
@@ -334,7 +333,7 @@ fn col_host(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleType
         scroll_host = scroll_host.push(Space::with_height(25)).push(
             Text::new(only_top_30_items_translation(language))
                 .font(font)
-                .horizontal_alignment(Horizontal::Center),
+                .align_x(Alignment::Center),
         );
     }
 
@@ -343,11 +342,11 @@ fn col_host(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleType
         .push(
             Row::new()
                 .height(45)
-                .align_items(Alignment::Center)
+                .align_y(Alignment::Center)
                 .push(
                     Text::new(host_translation(language))
                         .font(font)
-                        .style(TextType::Title)
+                        .class(TextType::Title)
                         .size(FONT_SIZE_TITLE),
                 )
                 .push(horizontal_space())
@@ -357,20 +356,22 @@ fn col_host(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleType
                 )),
         )
         .push(
-            Scrollable::new(scroll_host)
-                .width(Length::Fill)
-                .direction(Direction::Vertical(ScrollbarType::properties())),
+            Scrollable::with_direction(
+                scroll_host,
+                Direction::Vertical(ScrollbarType::properties()),
+            )
+            .width(Length::Fill),
         )
 }
 
-fn col_service(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleType> {
+fn col_service<'a>(width: f32, sniffer: &Sniffer) -> Column<'a, Message, StyleType> {
     let ConfigSettings {
         style, language, ..
     } = sniffer.configs.lock().unwrap().settings;
     let font = style.get_extension().font;
     let chart_type = sniffer.traffic_chart.chart_type;
 
-    let mut scroll_service = Column::new().width(width).align_items(Alignment::Center);
+    let mut scroll_service = Column::new().width(width).align_x(Alignment::Center);
     let entries = get_service_entries(&sniffer.info_traffic, chart_type, sniffer.service_sort_type);
     let first_entry_data_info = entries
         .iter()
@@ -402,11 +403,11 @@ fn col_service(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleT
 
         scroll_service = scroll_service.push(
             button(content)
-                .padding([5, 15, 8, 10])
+                .padding(Padding::new(5.0).right(15).bottom(8).left(10))
                 .on_press(Message::Search(SearchParameters::new_service_search(
                     service,
                 )))
-                .style(ButtonType::Neutral),
+                .class(ButtonType::Neutral),
         );
     }
 
@@ -414,7 +415,7 @@ fn col_service(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleT
         scroll_service = scroll_service.push(Space::with_height(25)).push(
             Text::new(only_top_30_items_translation(language))
                 .font(font)
-                .horizontal_alignment(Horizontal::Center),
+                .align_x(Alignment::Center),
         );
     }
 
@@ -423,11 +424,11 @@ fn col_service(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleT
         .push(
             Row::new()
                 .height(45)
-                .align_items(Alignment::Center)
+                .align_y(Alignment::Center)
                 .push(
                     Text::new(service_translation(language))
                         .font(font)
-                        .style(TextType::Title)
+                        .class(TextType::Title)
                         .size(FONT_SIZE_TITLE),
                 )
                 .push(horizontal_space())
@@ -437,18 +438,20 @@ fn col_service(width: f32, sniffer: &Sniffer) -> Column<'static, Message, StyleT
                 )),
         )
         .push(
-            Scrollable::new(scroll_service)
-                .width(Length::Fill)
-                .direction(Direction::Vertical(ScrollbarType::properties())),
+            Scrollable::with_direction(
+                scroll_service,
+                Direction::Vertical(ScrollbarType::properties()),
+            )
+            .width(Length::Fill),
         )
 }
 
-fn lazy_col_info(
+fn lazy_col_info<'a>(
     total: u128,
     filtered: u128,
     dropped: u32,
     sniffer: &Sniffer,
-) -> Container<'static, Message, StyleType> {
+) -> Container<'a, Message, StyleType> {
     let ConfigSettings {
         style, language, ..
     } = sniffer.configs.lock().unwrap().settings;
@@ -472,32 +475,36 @@ fn lazy_col_info(
     );
 
     let content = Column::new()
-        .align_items(Alignment::Center)
+        .align_x(Alignment::Center)
         .padding([5, 10])
         .push(
             Row::new()
                 .height(120)
                 .push(
-                    Scrollable::new(col_device)
-                        .width(Length::Fill)
-                        .direction(Direction::Horizontal(ScrollbarType::properties())),
+                    Scrollable::with_direction(
+                        col_device,
+                        Direction::Horizontal(ScrollbarType::properties()),
+                    )
+                    .width(Length::Fill),
                 )
                 .push(Container::new(Rule::vertical(25)).height(Length::Shrink))
                 .push(col_data_representation.width(Length::Fill)),
         )
         .push(Rule::horizontal(15))
         .push(
-            Scrollable::new(col_bytes_packets)
-                .height(Length::Fill)
-                .width(Length::Fill)
-                .direction(Direction::Vertical(ScrollbarType::properties())),
+            Scrollable::with_direction(
+                col_bytes_packets,
+                Direction::Vertical(ScrollbarType::properties()),
+            )
+            .height(Length::Fill)
+            .width(Length::Fill),
         );
 
     Container::new(content)
         .width(400)
-        .padding([10, 5, 5, 5])
-        .align_x(Horizontal::Center)
-        .style(ContainerType::BorderedRound)
+        .padding(Padding::new(5.0).top(10))
+        .align_x(Alignment::Center)
+        .class(ContainerType::BorderedRound)
 }
 
 fn container_chart(sniffer: &Sniffer, font: Font) -> Container<Message, StyleType> {
@@ -514,37 +521,37 @@ fn container_chart(sniffer: &Sniffer, font: Font) -> Container<Message, StyleTyp
 
     Container::new(
         Column::new()
-            .align_items(Alignment::Center)
+            .align_x(Alignment::Center)
             .push(
                 Row::new()
                     .padding([10, 0])
                     .spacing(10)
-                    .align_items(Alignment::Center)
+                    .align_y(Alignment::Center)
                     .push(
                         traffic_rate_translation(language)
                             .font(font)
-                            .style(TextType::Title)
+                            .class(TextType::Title)
                             .size(FONT_SIZE_TITLE),
                     )
                     .push(
                         Text::new(chart_info_string)
-                            .style(TextType::Subtitle)
+                            .class(TextType::Subtitle)
                             .font(font),
                     ),
             )
             .push(traffic_chart.view()),
     )
     .width(Fill)
-    .align_x(Horizontal::Center)
-    .align_y(Vertical::Center)
-    .style(ContainerType::BorderedRound)
+    .align_x(Alignment::Center)
+    .align_y(Alignment::Center)
+    .class(ContainerType::BorderedRound)
 }
 
-fn col_device(
+fn col_device<'a>(
     language: Language,
     font: Font,
     device: &MyDevice,
-) -> Column<'static, Message, StyleType> {
+) -> Column<'a, Message, StyleType> {
     let link_type = device.link_type;
     #[cfg(not(target_os = "windows"))]
     let adapter_info = &device.name;
@@ -562,14 +569,14 @@ fn col_device(
         .push(link_type.link_type_col(language, font))
 }
 
-fn col_data_representation(
+fn col_data_representation<'a>(
     language: Language,
     font: Font,
     chart_type: ChartType,
-) -> Column<'static, Message, StyleType> {
+) -> Column<'a, Message, StyleType> {
     let mut ret_val = Column::new().spacing(5).push(
         Text::new(format!("{}:", data_representation_translation(language)))
-            .style(TextType::Subtitle)
+            .class(TextType::Subtitle)
             .font(font),
     );
 
@@ -579,13 +586,13 @@ fn col_data_representation(
             Button::new(
                 Text::new(option.get_label(language).to_owned())
                     .width(Length::Fill)
-                    .horizontal_alignment(Horizontal::Center)
-                    .vertical_alignment(Vertical::Center)
+                    .align_x(Alignment::Center)
+                    .align_y(Alignment::Center)
                     .font(font),
             )
             .width(Length::Fill)
             .height(33)
-            .style(if is_active {
+            .class(if is_active {
                 ButtonType::BorderedRoundSelected
             } else {
                 ButtonType::BorderedRound
@@ -596,7 +603,7 @@ fn col_data_representation(
     ret_val
 }
 
-fn col_bytes_packets(
+fn col_bytes_packets<'a>(
     language: Language,
     dropped: u32,
     total: u128,
@@ -604,7 +611,7 @@ fn col_bytes_packets(
     font: Font,
     font_headers: Font,
     sniffer: &Sniffer,
-) -> Column<'static, Message, StyleType> {
+) -> Column<'a, Message, StyleType> {
     let filtered_bytes = sniffer.runtime_data.tot_out_bytes + sniffer.runtime_data.tot_in_bytes;
     let all_bytes = sniffer.runtime_data.all_bytes;
     let filters = &sniffer.filters;
@@ -729,36 +736,36 @@ fn get_bars_length(
     (in_len, out_len)
 }
 
-fn get_bars(in_len: f32, out_len: f32) -> Row<'static, Message, StyleType> {
+fn get_bars<'a>(in_len: f32, out_len: f32) -> Row<'a, Message, StyleType> {
     Row::new()
         .push(if in_len > 0.0 {
             Row::new()
                 .width(in_len)
-                .push(Rule::horizontal(1).style(RuleType::Incoming))
+                .push(Rule::horizontal(1).class(RuleType::Incoming))
         } else {
             Row::new()
         })
         .push(if out_len > 0.0 {
             Row::new()
                 .width(out_len)
-                .push(Rule::horizontal(1).style(RuleType::Outgoing))
+                .push(Rule::horizontal(1).class(RuleType::Outgoing))
         } else {
             Row::new()
         })
 }
 
-fn get_star_button(is_favorite: bool, host: Host) -> Button<'static, Message, StyleType> {
+fn get_star_button<'a>(is_favorite: bool, host: Host) -> Button<'a, Message, StyleType> {
     button(
         Icon::Star
             .to_text()
             .size(20)
-            .horizontal_alignment(Horizontal::Center)
-            .vertical_alignment(Vertical::Center),
+            .align_x(Alignment::Center)
+            .align_y(Alignment::Center),
     )
     .padding(0)
     .height(FLAGS_WIDTH_BIG * 0.75)
     .width(FLAGS_WIDTH_BIG)
-    .style(if is_favorite {
+    .class(if is_favorite {
         ButtonType::Starred
     } else {
         ButtonType::NotStarred
@@ -766,17 +773,17 @@ fn get_star_button(is_favorite: bool, host: Host) -> Button<'static, Message, St
     .on_press(Message::AddOrRemoveFavorite(host, !is_favorite))
 }
 
-fn get_active_filters_col(
+fn get_active_filters_col<'a>(
     filters: &Filters,
     language: Language,
     font: Font,
     font_headers: Font,
     show: bool,
-) -> Column<'static, Message, StyleType> {
+) -> Column<'a, Message, StyleType> {
     let mut ret_val = Column::new().push(
         Text::new(format!("{}:", active_filters_translation(language),))
             .font(font)
-            .style(TextType::Subtitle),
+            .class(TextType::Subtitle),
     );
 
     if filters.none_active() {
@@ -786,7 +793,7 @@ fn get_active_filters_col(
         ret_val = ret_val.push(if show {
             Row::new().push(Text::new(filters_string).font(font))
         } else {
-            Row::new().padding([0, 0, 0, 20]).push(
+            Row::new().padding(Padding::ZERO.left(20)).push(
                 Tooltip::new(
                     Container::new(
                         Text::new("i")
@@ -794,37 +801,37 @@ fn get_active_filters_col(
                             .size(15)
                             .line_height(LineHeight::Relative(1.0)),
                     )
-                    .align_x(Horizontal::Center)
-                    .align_y(Vertical::Center)
+                    .align_x(Alignment::Center)
+                    .align_y(Alignment::Center)
                     .height(20)
                     .width(20)
-                    .style(ContainerType::Highlighted),
+                    .class(ContainerType::Highlighted),
                     Text::new(filters_string).font(font),
                     Position::FollowCursor,
                 )
-                .style(ContainerType::Tooltip),
+                .class(ContainerType::Tooltip),
             )
         });
     }
     ret_val
 }
 
-fn sort_arrows(
+fn sort_arrows<'a>(
     active_sort_type: SortType,
     message: fn(SortType) -> Message,
-) -> Container<'static, Message, StyleType> {
+) -> Container<'a, Message, StyleType> {
     Container::new(
         button(
             active_sort_type
                 .icon()
-                .horizontal_alignment(Horizontal::Center)
-                .vertical_alignment(Vertical::Center),
+                .align_x(Alignment::Center)
+                .align_y(Alignment::Center),
         )
-        .style(active_sort_type.button_type())
+        .class(active_sort_type.button_type())
         .on_press(message(active_sort_type.next_sort())),
     )
     .width(60.0)
-    .align_x(Horizontal::Center)
+    .align_x(Alignment::Center)
 }
 
 #[cfg(test)]
