@@ -2,13 +2,13 @@
 
 #![allow(clippy::module_name_repetitions)]
 
-use iced::widget::checkbox::Appearance;
+use iced::widget::checkbox::{Catalog, Status, Style};
 use iced::{Background, Border};
 
 use crate::gui::styles::style_constants::BORDER_WIDTH;
 use crate::StyleType;
 
-#[derive(Clone, Copy, Default)]
+#[derive(Default)]
 pub enum CheckboxType {
     #[default]
     Standard,
@@ -16,13 +16,12 @@ pub enum CheckboxType {
 
 const CHECKBOX_BORDER_RADIUS: f32 = 5.0;
 
-impl iced::widget::checkbox::StyleSheet for StyleType {
-    type Style = CheckboxType;
-
-    fn active(&self, _: &Self::Style, is_checked: bool) -> Appearance {
-        let colors = self.get_palette();
-        let ext = self.get_extension();
-        Appearance {
+impl CheckboxType {
+    #[allow(clippy::unused_self)]
+    fn active(&self, style: &StyleType, is_checked: bool) -> Style {
+        let colors = style.get_palette();
+        let ext = style.get_extension();
+        Style {
             background: Background::Color(ext.buttons_color),
             icon_color: colors.text_body,
             border: Border {
@@ -34,10 +33,11 @@ impl iced::widget::checkbox::StyleSheet for StyleType {
         }
     }
 
-    fn hovered(&self, _: &Self::Style, _is_checked: bool) -> Appearance {
-        let colors = self.get_palette();
-        let ext = self.get_extension();
-        Appearance {
+    #[allow(clippy::unused_self)]
+    fn hovered(&self, style: &StyleType, _is_checked: bool) -> Style {
+        let colors = style.get_palette();
+        let ext = style.get_extension();
+        Style {
             background: Background::Color(ext.buttons_color),
             icon_color: colors.text_body,
             border: Border {
@@ -49,3 +49,20 @@ impl iced::widget::checkbox::StyleSheet for StyleType {
         }
     }
 }
+
+impl Catalog for StyleType {
+    type Class<'a> = CheckboxType;
+
+    fn default<'a>() -> Self::Class<'a> {
+        Self::Class::default()
+    }
+
+    fn style(&self, class: &Self::Class<'_>, status: Status) -> Style {
+        match status {
+            Status::Active { is_checked } | Status::Disabled { is_checked } => {
+                class.active(self, is_checked)
+            }
+            Status::Hovered { is_checked } => class.hovered(self, is_checked),
+        }
+    }
+}
