@@ -19,6 +19,10 @@ pub fn general_translation(language: Language) -> &'static str {
         Language::JA => "一般",
         Language::UZ => "Asosiy",
         Language::SV => "Allmänt",
+        Language::VI => "Tổng quan",
+        Language::ZH => "通用",
+        Language::KO => "일반",
+        Language::TR => "Genel",
         _ => "General",
     }
 }
@@ -37,6 +41,10 @@ pub fn zoom_translation(language: Language) -> &'static str {
         Language::RU => "Масштаб интерфейса",
         Language::JA => "ズーム",
         Language::UZ => "Kattalashtirish",
+        Language::VI => "Phóng to",
+        Language::ZH => "缩放",
+        Language::KO => "확대",
+        Language::TR => "Yakınlaştırma",
         _ => "Zoom",
     }
 }
@@ -55,6 +63,10 @@ pub fn mmdb_files_translation(language: Language) -> &'static str {
         Language::JA => "データベース ファイル",
         Language::UZ => "Ma'lumotlar bazasi fayllari",
         Language::SV => "Databasfiler",
+        Language::VI => "Tập tin cơ sở dữ liệu",
+        Language::ZH => "数据库文件",
+        Language::KO => "데이터베이스 파일",
+        Language::TR => "Veri tabanı dosyaları",
         _ => "Database files",
     }
 }
@@ -66,13 +78,17 @@ pub fn params_not_editable_translation(language: Language) -> &'static str {
         Language::ES => "Los siguientes parámetros no pueden modificarse durante el análisis",
         Language::IT => "I seguenti parametri non sono modificabili durante l'analisi",
         Language::FR => "Les paramètres suivants ne peuvent pas être modifiés durant l'analyse",
-        Language::DE => "Die folgenden Paramter können während der Analyse nicht verändert werden",
+        Language::DE => "Die folgenden Parameter können während der Analyse nicht verändert werden",
         Language::PL => "Następujące parametry nie mogą być modyfikowane podczas analizy",
         Language::RU => "Следующие параметры не могут быть изменены во время анализа трафика",
         Language::RO => "Următorii parametri nu sunt modificabili în timpul analizei",
         Language::JA => "以下のパラメーターは分析中は変更できません",
         Language::UZ => "Tahlil vaqtida quydagi parametrlarni o'zgartirib bo'lmaydi",
         Language::SV => "Följande parametrar kan inte ändras under analysen",
+        Language::VI => "Các tham số sau không thể bị thay đổi khi đang phân tích",
+        Language::ZH => "以下参数在分析过程中不能修改",
+        Language::KO => "분석 중 다음의 매개변수들은 수정할 수 없습니다",
+        Language::TR => "Analiz sırasında bu parametrelere müdahale edilemez",
         _ => "The following parameters can't be modified during the analysis",
     }
 }
@@ -91,6 +107,10 @@ pub fn custom_style_translation(language: Language) -> &'static str {
         Language::JA => "カスタム スタイル",
         Language::UZ => "Moslashtirilgan uslub",
         Language::SV => "Anpassad stil",
+        Language::VI => "Tùy chỉnh chủ đề",
+        Language::ZH => "自定义样式",
+        Language::KO => "사용자 지정 스타일",
+        Language::TR => "Kişisel görünüm",
         _ => "Custom style",
     }
 }
@@ -107,6 +127,10 @@ pub fn copy_translation(language: Language) -> &'static str {
         Language::JA => "コピー",
         Language::UZ => "Nusxalash",
         Language::SV => "Kopia",
+        Language::VI => "Sao chép",
+        Language::ZH => "复制",
+        Language::KO => "복사",
+        Language::TR => "Kopyala",
         _ => "Copy",
     }
 }
@@ -119,12 +143,16 @@ pub fn port_translation(language: Language) -> &'static str {
         | Language::PL
         | Language::RO
         | Language::UZ
-        | Language::SV => "Port",
+        | Language::SV
+        | Language::TR => "Port",
         // Language::FA => "درگاه",
         Language::ES => "Puerto",
         Language::IT => "Porta",
         Language::RU => "Порт",
         Language::JA => "ポート",
+        Language::VI => "Cổng",
+        Language::ZH => "端口",
+        Language::KO => "포트",
         _ => "Port",
     }
 }
@@ -143,6 +171,10 @@ pub fn invalid_filters_translation(language: Language) -> &'static str {
         Language::JA => "無効なフィルター",
         Language::UZ => "Noto'g'ri filterlar",
         Language::SV => "Ogiltiga filter",
+        Language::VI => "Bộ lọc không khả dụng",
+        Language::ZH => "无效的过滤器",
+        Language::KO => "잘못된 필터",
+        Language::TR => "Geçersiz filtreler",
         _ => "Invalid filters",
     }
 }
@@ -160,6 +192,10 @@ pub fn messages_translation(language: Language) -> &'static str {
         Language::JA => "メッセージ",
         Language::UZ => "Xabarlar",
         Language::SV => "Meddelanden",
+        Language::VI => "Tin nhắn",
+        Language::ZH => "信息",
+        Language::KO => "메시지",
+        Language::TR => "Mesajlar",
         _ => "Messages",
     }
 }
@@ -178,14 +214,18 @@ pub fn link_type_translation(language: Language) -> &'static str {
         Language::JA => "リンク タイプ",
         Language::UZ => "Havola turi",
         Language::SV => "Länktyp",
+        Language::VI => "Loại liên kết",
+        Language::ZH => "链接类型",
+        Language::KO => "링크 유형",
+        Language::TR => "Link türü",
         _ => "Link type",
     }
 }
 
-pub fn unsupported_link_type_translation(
+pub fn unsupported_link_type_translation<'a>(
     language: Language,
     adapter: &str,
-) -> Text<'static, StyleType> {
+) -> Text<'a, StyleType> {
     let translation = match language {
         Language::EN => "The link type associated with this adapter is not supported by Sniffnet yet...",
         // Language::FA => "نوع پیوند مرتبط با این مبدل هنوز توسط Sniffnet پشتیبانی نمی شود...",
@@ -199,6 +239,10 @@ pub fn unsupported_link_type_translation(
         Language::JA => "このアダプターのリンク タイプは Sniffnet ではまだサポートされていません...",
         Language::UZ => "Ushbu adapter bilan bog'langan havola turi hozircha Sniffnet tomonidan qo'llab quvvatlanmaydi...",
         Language::SV => "Länktypen associerad med denna adapter stöds inte av Sniffnet än...",
+        Language::VI => "Loại liên kết được gắn với adapter này chưa được Sniffnet hỗ trợ...",
+        Language::ZH => "Sniffnet 尚不支持与此适配器关联的链接类型...",
+        Language::KO => "이 어댑터와 연결된 링크 유형은 Sniffnet에서 아직 지원되지 않습니다...",
+        Language::TR => "Bu adaptör ile ilişkilendirilmiş link türü henüz Sniffnet tarafından desteklenmiyor...",
         _ => "The link type associated with this adapter is not supported by Sniffnet yet...",
     };
 
@@ -222,6 +266,10 @@ pub fn style_from_file_translation(language: Language) -> &'static str {
         Language::JA => "ファイルからスタイルを選択してください",
         Language::UZ => "Fayldan uslubni tanlang",
         Language::SV => "Välj stil från en fil",
+        Language::VI => "Chọn chủ đề từ file của bạn",
+        Language::ZH => "从文件中选择样式",
+        Language::KO => "파일에서 스타일을 선택하세요",
+        Language::TR => "Dosyadan bir görünüm seç",
         _ => "Select style from a file",
     }
 }
@@ -240,6 +288,10 @@ pub fn database_from_file_translation(language: Language) -> &'static str {
         Language::JA => "データベース ファイルを選択してください",
         Language::UZ => "Ma'lumotlar bazasi faylini tanlang",
         Language::SV => "Välj databasfil",
+        Language::VI => "Chọn tập tin cơ sở dữ liệu",
+        Language::ZH => "选择数据库文件",
+        Language::KO => "데이터베이스 파일 선택",
+        Language::TR => "Veri tabanı dosyası seç",
         _ => "Select database file",
     }
 }
@@ -258,6 +310,10 @@ pub fn filter_by_host_translation(language: Language) -> &'static str {
         Language::JA => "ネットワーク ホストでフィルター",
         Language::UZ => "Tarmoq host bo'yicha filterlash",
         Language::SV => "Filtrera efter nätverksvärd",
+        Language::VI => "Lọc bởi máy chủ mạng",
+        Language::ZH => "按网络主机筛选",
+        Language::KO => "네트워크 호스트로 필터링",
+        Language::TR => "Ağ sunucusuna göre filtrele",
         _ => "Filter by network host",
     }
 }
@@ -273,6 +329,10 @@ pub fn service_translation(language: Language) -> &'static str {
         Language::RO => "Serviciu",
         Language::JA => "サービス",
         Language::UZ => "Xizmat",
+        Language::VI => "Dịch vụ",
+        Language::ZH => "服务",
+        Language::KO => "서비스",
+        Language::TR => "Servis",
         _ => "Service",
     }
 }
@@ -290,6 +350,10 @@ pub fn export_capture_translation(language: Language) -> &'static str {
         Language::JA => "キャプチャ ファイルをエクスポート",
         Language::UZ => "Cap faylni export qilish",
         Language::SV => "Exportera inspelningsfil",
+        Language::VI => "Xuất tập tin đã bắt",
+        Language::ZH => "导出捕获文件",
+        Language::KO => "캡처 파일 내보내기",
+        Language::TR => "Yakalanan dosyayı dışa aktar",
         _ => "Export capture file",
     }
 }
@@ -306,6 +370,10 @@ pub fn directory_translation(language: Language) -> &'static str {
         Language::RU => "Директория",
         Language::RO => "Director",
         Language::JA => "ディレクトリー",
+        Language::VI => "Thư mục",
+        Language::ZH => "目录",
+        Language::KO => "디렉토리",
+        Language::TR => "Klasör",
         _ => "Directory",
     }
 }
@@ -316,13 +384,17 @@ pub fn select_directory_translation(language: Language) -> &'static str {
         // Language::FA => "انتخاب پوشه مقصد",
         Language::IT => "Seleziona cartella di destinazione",
         Language::FR => "Sélectionner le répertoire de destination",
-        Language::DE => "Zielorder wählen",
+        Language::DE => "Zielordner wählen",
         Language::PL => "Wybierz katalog docelowy", // "Wybierz folder docelowy"?
         Language::RU => "Выберите директорию назначения",
         Language::RO => "Selectează directorul destinație",
         Language::JA => "宛先のディレクトリーを選択する",
         Language::UZ => "Manzil katalogni tanlang",
         Language::SV => "Välj målkatalog",
+        Language::VI => "Chọn thư mục đích đến",
+        Language::ZH => "选择目标目录",
+        Language::KO => "대상 디렉토리 선택",
+        Language::TR => "Hedef klasörü seç",
         _ => "Select destination directory",
     }
 }
@@ -340,6 +412,10 @@ pub fn file_name_translation(language: Language) -> &'static str {
         Language::JA => "ファイル ネーム",
         Language::UZ => "Fayl nomi",
         Language::SV => "Filnamn",
+        Language::VI => "Tên file",
+        Language::ZH => "文件名",
+        Language::KO => "파일 이름",
+        Language::TR => "Dosya adı",
         _ => "File name",
     }
 }
@@ -357,6 +433,10 @@ pub fn thumbnail_mode_translation(language: Language) -> &'static str {
         Language::JA => "サムネイル モード",
         Language::UZ => "Eskiz rejim",
         Language::SV => "Miniatyrläge",
+        Language::VI => "Chế độ thu nhỏ",
+        Language::ZH => "缩略图模式",
+        Language::KO => "썸네일 모드",
+        Language::TR => "Küçük resim modu",
         _ => "Thumbnail mode",
     }
 }
@@ -374,6 +454,10 @@ pub fn learn_more_translation(language: Language) -> &'static str {
         Language::JA => "もっと知りたいですか？",
         Language::UZ => "Ko'proq bilishni hohlaysizmi?",
         Language::SV => "Vill du veta mer?",
+        Language::VI => "Bạn có muốn tìm hiểu thêm?",
+        Language::ZH => "想知道更多吗？",
+        Language::KO => "더 자세히 알고 싶으십니까?",
+        Language::TR => "Daha fazlasını öğrenmek ister misin?",
         _ => "Do you want to learn more?",
     }
 }
